Fixed an issue causing a wrong window title when a UML diagram was loaded. 6_1_x

Sat, 09 Jan 2016 17:19:05 +0100

author
Detlev Offenbach <detlev@die-offenbachs.de>
date
Sat, 09 Jan 2016 17:19:05 +0100
branch
6_1_x
changeset 4646
cf9cb65c30dc
parent 4644
99699903c454
child 4657
ce42b7df7fc8

Fixed an issue causing a wrong window title when a UML diagram was loaded.
(grafted from 3d6762252f046c794319f211298e788a7e92041f)

Graphics/UMLDialog.py file | annotate | diff | comparison | revisions
--- a/Graphics/UMLDialog.py	Sat Jan 09 10:53:04 2016 +0100
+++ b/Graphics/UMLDialog.py	Sat Jan 09 17:19:05 2016 +0100
@@ -362,8 +362,11 @@
             self.__showInvalidDataMessage(filename)
             return False
         
-        # everything worked fine, so remember the file name
+        # everything worked fine, so remember the file name and set the
+        # window title
+        self.setWindowTitle(self.__diagramTypeString())
         self.__fileName = filename
+        
         return True
     
     def __showInvalidDataMessage(self, filename, linenum=-1):

eric ide

mercurial